@@ -11,9 +11,6 @@
 
 from __future__ import print_function, unicode_literals
 
-import sys
-sys.path.append("..")
-
 import pyte
 
 
